<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="2.0" language="fr" sourcelanguage="">
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="config.py" line="24"/>
        <source>Behavior</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="24"/>
        <source>Automatically save documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="24"/>
        <source>Restore window geometry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="24"/>
        <source>Restore live preview state</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="24"/>
        <source>Open external links in ReText window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="24"/>
        <source>Open unknown files in plain text mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="24"/>
        <source>Editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="24"/>
        <source>Highlight current line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="24"/>
        <source>Show line numbers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="24"/>
        <source>Tab key inserts spaces</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="24"/>
        <source>Tabulation width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="24"/>
        <source>Display right margin at column</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="24"/>
        <source>Interface</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="24"/>
        <source>Icon theme name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <location filename="dialogs.py" line="34"/>
        <source>Enter locale name (example: en_US)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dialogs.py" line="39"/>
        <source>Set as default</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ReTextWindow</name>
    <message>
        <location filename="window.py" line="92"/>
        <source>File toolbar</source>
        <translation>Barre d&apos;outil Fichier</translation>
    </message>
    <message>
        <location filename="window.py" line="94"/>
        <source>Edit toolbar</source>
        <translation>Barre d&apos;outil Édition</translation>
    </message>
    <message>
        <location filename="window.py" line="96"/>
        <source>Search toolbar</source>
        <translation>Barre d&apos;outil de recherche</translation>
    </message>
    <message>
        <location filename="window.py" line="100"/>
        <source>New</source>
        <translation>Nouveau</translation>
    </message>
    <message>
        <location filename="window.py" line="103"/>
        <source>Open</source>
        <translation>Ouvrir</translation>
    </message>
    <message>
        <location filename="window.py" line="109"/>
        <source>Save</source>
        <translation>Enregistrer</translation>
    </message>
    <message>
        <location filename="window.py" line="113"/>
        <source>Save as</source>
        <translation>Enregistrer Sous</translation>
    </message>
    <message>
        <location filename="window.py" line="115"/>
        <source>Print</source>
        <translation>Imprimer</translation>
    </message>
    <message>
        <location filename="window.py" line="118"/>
        <source>Print preview</source>
        <translation>Aperçu avant impression</translation>
    </message>
    <message>
        <location filename="window.py" line="120"/>
        <source>View HTML code</source>
        <translation>Voir le code HTML</translation>
    </message>
    <message>
        <location filename="window.py" line="121"/>
        <source>Change default font</source>
        <translation>Changer la police par défaut</translation>
    </message>
    <message>
        <location filename="window.py" line="122"/>
        <source>Find text</source>
        <translation>Rechercher un texte</translation>
    </message>
    <message>
        <location filename="window.py" line="126"/>
        <source>Preview</source>
        <translation>Aperçu</translation>
    </message>
    <message>
        <location filename="window.py" line="135"/>
        <source>Live preview</source>
        <translation>Aperçu direct</translation>
    </message>
    <message>
        <location filename="window.py" line="137"/>
        <source>Fullscreen mode</source>
        <translation>Mode plein écran</translation>
    </message>
    <message>
        <location filename="window.py" line="145"/>
        <source>Quit</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <location filename="window.py" line="148"/>
        <source>Undo</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="window.py" line="150"/>
        <source>Redo</source>
        <translation>Rétablir</translation>
    </message>
    <message>
        <location filename="window.py" line="152"/>
        <source>Copy</source>
        <translation>Copier</translation>
    </message>
    <message>
        <location filename="window.py" line="154"/>
        <source>Cut</source>
        <translation>Couper</translation>
    </message>
    <message>
        <location filename="window.py" line="156"/>
        <source>Paste</source>
        <translation>Coller</translation>
    </message>
    <message>
        <location filename="window.py" line="166"/>
        <source>Enable</source>
        <translation>Activer</translation>
    </message>
    <message>
        <location filename="window.py" line="167"/>
        <source>Set locale</source>
        <translation>Choisir la langue</translation>
    </message>
    <message>
        <location filename="window.py" line="168"/>
        <source>Plain text</source>
        <translation>Texte brut</translation>
    </message>
    <message>
        <location filename="window.py" line="169"/>
        <source>Use WebKit renderer</source>
        <translation>Utiliser le rendu de WebKit</translation>
    </message>
    <message>
        <location filename="window.py" line="171"/>
        <source>Generate webpages</source>
        <translation>Générer les pages web</translation>
    </message>
    <message>
        <location filename="window.py" line="172"/>
        <source>Show</source>
        <translation>Afficher</translation>
    </message>
    <message>
        <location filename="window.py" line="173"/>
        <source>Next</source>
        <translation>Suivant</translation>
    </message>
    <message>
        <location filename="window.py" line="175"/>
        <source>Previous</source>
        <translation>Précédent</translation>
    </message>
    <message>
        <location filename="window.py" line="177"/>
        <source>Get help online</source>
        <translation>Assistance en ligne</translation>
    </message>
    <message>
        <location filename="window.py" line="178"/>
        <source>About %s</source>
        <comment>Example of final string: About ReText</comment>
        <translation>À propos de %s</translation>
    </message>
    <message>
        <location filename="window.py" line="182"/>
        <source>About Qt</source>
        <translation>À propos de Qt</translation>
    </message>
    <message>
        <location filename="window.py" line="202"/>
        <source>Bold</source>
        <translation>Gras</translation>
    </message>
    <message>
        <location filename="window.py" line="204"/>
        <source>Italic</source>
        <translation>Italique</translation>
    </message>
    <message>
        <location filename="window.py" line="206"/>
        <source>Underline</source>
        <translation>Souligné</translation>
    </message>
    <message>
        <location filename="window.py" line="214"/>
        <source>Tags</source>
        <translation>Mots-clefs</translation>
    </message>
    <message>
        <location filename="window.py" line="218"/>
        <source>Symbols</source>
        <translation>Symboles</translation>
    </message>
    <message>
        <location filename="window.py" line="231"/>
        <source>File</source>
        <translation>Fichier</translation>
    </message>
    <message>
        <location filename="window.py" line="232"/>
        <source>Edit</source>
        <translation>Édition</translation>
    </message>
    <message>
        <location filename="window.py" line="233"/>
        <source>Help</source>
        <translation>Aide</translation>
    </message>
    <message>
        <location filename="window.py" line="236"/>
        <source>Open recent</source>
        <translation>Ouvrir les fichiers récents</translation>
    </message>
    <message>
        <location filename="window.py" line="239"/>
        <source>Directory</source>
        <translation>Répertoire</translation>
    </message>
    <message>
        <location filename="window.py" line="247"/>
        <source>Export</source>
        <translation>Exporter</translation>
    </message>
    <message>
        <location filename="window.py" line="269"/>
        <source>Spell check</source>
        <translation>Vérifier l&apos;orthographe</translation>
    </message>
    <message>
        <location filename="window.py" line="280"/>
        <source>Formatting</source>
        <translation>Formatage</translation>
    </message>
    <message>
        <location filename="window.py" line="317"/>
        <source>Search</source>
        <translation>Rechercher</translation>
    </message>
    <message>
        <location filename="window.py" line="319"/>
        <source>Case sensitively</source>
        <translation>Sensible à la casse</translation>
    </message>
    <message>
        <location filename="window.py" line="1135"/>
        <source>New document</source>
        <translation>Nouveau document</translation>
    </message>
    <message>
        <location filename="window.py" line="765"/>
        <source>Please, save the file somewhere.</source>
        <translation>Veuillez enregistrer le fichier quelque part.</translation>
    </message>
    <message>
        <location filename="window.py" line="754"/>
        <source>Webpages saved in &lt;code&gt;html&lt;/code&gt; directory.</source>
        <translation>Pages web enregistrées dans le répertoire &lt;code&gt;html&lt;/code&gt;.</translation>
    </message>
    <message>
        <location filename="window.py" line="756"/>
        <source>Show directory</source>
        <translation>Afficher le répertoire</translation>
    </message>
    <message>
        <location filename="window.py" line="880"/>
        <source>Select one or several files to open</source>
        <translation>Choisir un ou plusieurs fichiers à ouvrir</translation>
    </message>
    <message>
        <location filename="window.py" line="880"/>
        <source>Supported files</source>
        <translation>Formats acceptés</translation>
    </message>
    <message>
        <location filename="window.py" line="880"/>
        <source>All files (*)</source>
        <translation>Tous les fichiers (*)</translation>
    </message>
    <message>
        <location filename="window.py" line="962"/>
        <source>Plain text (*.txt)</source>
        <translation>Fichier text (*.txt)</translation>
    </message>
    <message>
        <location filename="window.py" line="1038"/>
        <source>Save file</source>
        <translation>Enregistrer le fichier</translation>
    </message>
    <message>
        <location filename="window.py" line="984"/>
        <source>Cannot save to file because it is read-only!</source>
        <translation>Impossible d&apos;enregistrer le fichier car il est en lecture seule !</translation>
    </message>
    <message>
        <location filename="window.py" line="1029"/>
        <source>Export document to ODT</source>
        <translation>Exporter le document au format ODT</translation>
    </message>
    <message>
        <location filename="window.py" line="1029"/>
        <source>OpenDocument text files (*.odt)</source>
        <translation>Fichiers OpenDocument texte (*.odt)</translation>
    </message>
    <message>
        <location filename="window.py" line="1038"/>
        <source>HTML files (*.html *.htm)</source>
        <translation>Fichier HTML (*.html, *.htm)</translation>
    </message>
    <message>
        <location filename="window.py" line="1059"/>
        <source>Export document to PDF</source>
        <translation>Exporter le document au format PDF</translation>
    </message>
    <message>
        <location filename="window.py" line="1059"/>
        <source>PDF files (*.pdf)</source>
        <translation>Fichiers PDF (*.pdf)</translation>
    </message>
    <message>
        <location filename="window.py" line="1075"/>
        <source>Print document</source>
        <translation>Imprimer le document</translation>
    </message>
    <message>
        <location filename="window.py" line="1096"/>
        <source>Export document</source>
        <translation>Exporter le document</translation>
    </message>
    <message>
        <location filename="window.py" line="1114"/>
        <source>Failed to execute the command:</source>
        <translation>Échec lors de l&apos;exécution de la commande :</translation>
    </message>
    <message>
        <location filename="window.py" line="1191"/>
        <source>The document has been modified.
Do you want to save your changes?</source>
        <translation>Le document a modifié.
Voulez vous enregistrer vos changements ?</translation>
    </message>
    <message>
        <location filename="window.py" line="1215"/>
        <source>HTML code</source>
        <translation>Code HTML</translation>
    </message>
    <message>
        <location filename="window.py" line="1226"/>
        <source>Simple but powerful editor for Markdown and reStructuredText</source>
        <translation>Éditeur simple mais puissant pour Markdown et reStructuredText</translation>
    </message>
    <message>
        <location filename="window.py" line="1226"/>
        <source>Author: Dmitry Shachnev, 2011</source>
        <translation>Auteur: Dmitry Shachnev, 2011</translation>
    </message>
    <message>
        <location filename="window.py" line="1226"/>
        <source>Website</source>
        <translation>Site Web</translation>
    </message>
    <message>
        <location filename="window.py" line="1226"/>
        <source>Markdown syntax</source>
        <translation>Syntaxe Markdown</translation>
    </message>
    <message>
        <location filename="window.py" line="1226"/>
        <source>reStructuredText syntax</source>
        <translation>Syntaxe reStructuredText</translation>
    </message>
    <message>
        <location filename="window.py" line="965"/>
        <source>%s files</source>
        <comment>Example of final string: Markdown files</comment>
        <translation>Fichiers %s</translation>
    </message>
    <message>
        <location filename="window.py" line="750"/>
        <source>Failed to copy default template, please create template.html manually.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="661"/>
        <source>Could not parse file contents, check if you have the &lt;a href=&quot;%s&quot;&gt;necessary module&lt;/a&gt; installed!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="277"/>
        <source>Default markup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="586"/>
        <source>Preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="106"/>
        <source>Set encoding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="937"/>
        <source>Select file encoding from the list:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
